<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  同一ＩＰで指定時間以内のアクセスログ情報の取得
 *
 *  @access public
 *  @param  string  $ip                 IPアドレス
 *  @param  integer $offset             システム日付からのオフセット値（分数）
 */
function db_get_accessLog4duplicationCheck($ip, $offset)
{
    $sql = 'SELECT access_log_id' .
            ' FROM pbb_access_log' .
            ' WHERE ip = ?';

    // DB種別の判定
    if (pocket_db_isMySQL())
    {
        $sql .= ' AND r_datetime > DATE_ADD(?, INTERVAL ? MINUTE)';
    }
    else {
        $sql .= " AND r_datetime > (TIMESTAMP ? + INTERVAL '? MINUTE')";
    }

    $params = array(
        $ip,
        pocket_db_getNow(),
        intval($offset)
    );
    return pocket_db_getOne($sql, $params);
}

/**
 *  指定された日付のアクセス件数を取得
 *
 *  @access public
 *  @param  integer $offset             システム日付からのオフセット値（日数）
 */
function db_get_accessCount4day($offset = 0)
{
    $sql = 'SELECT count(access_log_id)' .
            ' FROM pbb_access_log';

    // DB種別の判定
    if (pocket_db_isMySQL())
    {
        $sql .= " WHERE DATE_FORMAT(r_datetime, '%Y%m%d') = DATE_FORMAT(DATE_ADD(?, INTERVAL ? DAY), '%Y%m%d')";
    }
    else {
        $sql .= " WHERE TO_CHAR(r_datetime, 'YYYYMMDD') = TO_CHAR((TIMESTAMP ? + INTERVAL '? DAY'), 'YYYYMMDD')";
    }

    $params = array(
        pocket_db_getNow(),
        intval($offset)
    );
    return pocket_db_getOne($sql, $params);
}

/**
 *  累計のアクセス件数を取得
 *
 *  @access public
 */
function db_get_accessCount4total()
{
    $sql = 'SELECT count(access_log_id)' .
            ' FROM pbb_access_log';
    return pocket_db_getOne($sql);
}

/**
 *  アクセスログ情報の登録
 *
 *  @access public
 *  @param  string  $user_agent         ユーザエージェント
 *  @param  string  $ip                 IPアドレス
 *  @param  string  $host               ホスト名
 *  @param  string  $uri                URI
 *  @param  string  $referer            リファラ
 */
function db_insert_accessLog($user_agent, $ip, $host, $uri, $referer)
{
    $data = array(
        'user_agent' => $user_agent,
        'ip' => $ip,
        'host' => $host,
        'uri' => $uri,
        'referer' => $referer,
        'r_datetime' => pocket_db_getNow()
    );
    return pocket_db_insert('pbb_access_log', $data, 'pbb_access_log_access_log_id_seq');
}

?>
