<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  トピック削除確認画面表示用のActionクラス
 *
 *  @author     Shogo Minami
 *  @access     public
 *  @package    PocketBBS.pc.view
 */
class topicDeleteConfirmAction extends Pocket_Bbs_Action
{
    /**
     *  アクション実行
     *
     *  @access public
     *  @param  object  $controller         コントローラ
     *  @param  object  $request            リクエスト情報
     *  @return string  success,error
     */
    function execute(&$controller, &$request)
    {
        // リクエスト情報の取得
        $topic_id        = $request['topic_id'];
        $author_password = $request['author_password'];

        /**
         *  メイン情報の取得、設定
         */
        // 暗号化されていないパスワード情報の設定
        $this->assign('author_password', $author_password);

        // トピック情報の取得、設定
        $topic = db_get_topic_info($topic_id);
        $this->assign('topic', $topic);

        /**
         *  基本情報の設定
         */
        // ページタイトルの設定
        $this->assign('page_title', 'トピックの削除');

        // サイドメニュー情報の設定
        $this->assignSideMenuInfo();

        return POCKET_ACTION_SUCCESS;
    }

    /**
     *  リクエスト検証
     *
     *  @access public
     *  @param  object  $validator          バリデータ
     *  @param  object  $request            リクエスト情報
     */
    function validate(&$validator, &$request)
    {
        // 認証チェック
        if (!pocket_isAuth())
        {
            // リクエスト情報の取得
            $topic_id        = $request['topic_id'];
            $author_password = $request['author_password'];

            // エラー表示用のAction名称の設定
            $this->viewAction = 'topicEditConfirm';

            // 検証
            $validator->validate('author_password', '暗証番号', $author_password, 'alnum'      , true);
            $validator->validate('author_password', '暗証番号', $author_password, '/^[\w]{4}$/', true);

            // トピック情報の存在チェック
            if (!db_get_topic_info($topic_id))
                pocket_redirect('default.view');

            // トピックのパスワード認証
            if (!db_auth_topic4author_password($topic_id, md5($author_password)))
            {
                $validator->addErrors('author_password', '認証に失敗しました。');
            }

            // 有効チェック
            if (!$validator->isValid())
            {
                // エラーメッセージをクリア
                $validator->clearErrors();
                $validator->addErrors('author_password', '認証に失敗しました。');
            }
        }
    }
}

?>
